from beneath._version import __version__
from beneath.client import Client
from beneath.connection import GraphQLError

__all__ = [
  "Client",
  "GraphQLError",
]
